==> schedule_package-0.0.6.tar.gz: lib/src/schedule_package.dart <==
import 'package:html/parser.dart' show parse;
import 'package:schedule_package/src/ScheduleModels/Schedule.dart';
import 'package:schedule_package/src/ScheduleModels/ScheduleWeek.dart';
import 'package:schedule_package/src/Supports/Decoder.dart';
import 'package:universal_html/parsing.dart' show parseHtmlDocument;

import '../src/ScheduleModels/Group.dart';
import "package:http/http.dart" as http;

import '../src/Supports/GlobalVariable.dart';

// Получает все группы которые есть на сайте
Future<List<Group>> getAllGroupsFuture() async {
  List<Group> groupsList = [];
  final response =
      await http.Client().get(Uri.parse(GlobalVariable.URL_MAIN + "/cg.htm"));
  if (response.statusCode == 200) {
    var body = decodeCp1251(response.body);
    var document = parse(body, encoding: 'windows-1251');
    var table = document
        .getElementsByClassName("inf")[0]
        .getElementsByTagName("tbody")[0];
    var res = table.getElementsByTagName("tr").length-1;
    for (int i = 1; i <= res; i++) {
      var nameGroup = table
          .getElementsByTagName("tr")[i]
          .getElementsByTagName("td")[1]
          .text;
      var linkGroup = table
          .getElementsByTagName("tr")[i]
          .getElementsByTagName("td")[1]
          .getElementsByTagName("a")[0]
          .attributes;
      groupsList.add(Group(nameGroup, linkGroup["href"].toString()));
    }
  }
  return groupsList;
}

//Получает расписание группы по его Линку (ID)
Future<List<Schedule>> getScheduleFuture(String groupLink) async {
  List<Schedule> scheduleList = new List.empty();
  final response =
      await http.Client().get(Uri.parse(GlobalVariable.URL_MAIN + groupLink));
  if (response.statusCode == 200) {
    var body = decodeCp1251(response.body);
    var documentFullHtmlCode = parseHtmlDocument(body);
    var documentTableHtmlCode =
        documentFullHtmlCode.querySelectorAll("table.inf").first;
    var documentTableElements = documentTableHtmlCode.querySelectorAll("tr");
    int count = documentTableElements.length;
    for (int i = 3; i < count; i++) {
      var documentTableSelected = documentTableElements[i];

      String firstLesson = "",
          firstCabinet = "",
          firstTeacher = "",
          dayParams = "";

      int count = documentTableSelected.querySelectorAll("tr > td.ur").length;
      print(count.toString());

      if (documentTableSelected.querySelector("tr > td.hd") != null)
        dayParams = documentTableSelected.querySelector("tr > td.hd")!.text!;
      if (documentTableSelected.querySelector("tr > td.ur > a.z1") != null)
        firstLesson =
            documentTableSelected.querySelector("tr > td.ur > a.z1")!.text!;
      if (documentTableSelected.querySelector("tr > td.ur > a.z2") != null)
        firstCabinet =
            documentTableSelected.querySelector("tr > td.ur > a.z2")!.text!;
      if (documentTableSelected.querySelector("tr > td.ur > a.z3") != null)
        firstTeacher =
            documentTableSelected.querySelector("tr > td.ur > a.z3")!.text!;

      if (isFirstElement(dayParams)) {
        if (count == 2) {
          scheduleList.add(new Schedule(dayParams, firstLesson, firstCabinet,
              firstTeacher, "", true, true, false, "1"));
        } else {
          scheduleList.add(new Schedule(dayParams, firstLesson, firstCabinet,
              firstTeacher, "", true, true, false, "1"));
        }
      } else if (dayParams == "2" || dayParams == "4" || dayParams == "6") {
        scheduleList.add(new Schedule(dayParams, firstLesson, firstCabinet,
            firstTeacher, "", false, false, true, dayParams));
      } else {
        if (count == 2) {
          scheduleList.add(new Schedule(dayParams, firstLesson, firstCabinet,
              firstTeacher, "", false, true, false, dayParams));
        } else {
          scheduleList.add(new Schedule(dayParams, firstLesson, firstCabinet,
              firstTeacher, "", false, false, false, dayParams));
        }
      }
    }
  }
  return scheduleList;
}

Future<List<Schedule>> getScheduleWeek(String groupLink) async {
  List<ScheduleWeek> scheduleWeekList = [];
  List<Schedule> scheduleList = [];
  final response =
  await http.Client().get(Uri.parse(GlobalVariable.URL_MAIN + groupLink));
  if (response.statusCode == 200) {
    var body = decodeCp1251(response.body);
    var documentFullHtmlCode = parseHtmlDocument(body);
    var documentTableHtmlCode =
        documentFullHtmlCode.querySelectorAll("table.inf").first;
    var documentTableElements = documentTableHtmlCode.querySelectorAll("tr");
    int count = documentTableElements.length;
    for (int i = 3; i < count; i++) {
      var documentTableSelected = documentTableElements[i];

      String firstLesson = "",
          firstCabinet = "",
          firstTeacher = "",
          dayParams = "";

      int count = documentTableSelected.querySelectorAll("tr > td.ur").length;
      print(count.toString());

      if (documentTableSelected.querySelector("tr > td.hd") != null)
        dayParams = documentTableSelected.querySelector("tr > td.hd")!.text!;
      if (documentTableSelected.querySelector("tr > td.ur > a.z1") != null)
        firstLesson =
        documentTableSelected.querySelector("tr > td.ur > a.z1")!.text!;
      if (documentTableSelected.querySelector("tr > td.ur > a.z2") != null)
        firstCabinet =
        documentTableSelected.querySelector("tr > td.ur > a.z2")!.text!;
      if (documentTableSelected.querySelector("tr > td.ur > a.z3") != null)
        firstTeacher =
        documentTableSelected.querySelector("tr > td.ur > a.z3")!.text!;

      if (isFirstElement(dayParams)) {
        if (count == 2) {
          scheduleList.add(new Schedule(dayParams, firstLesson, firstCabinet,
              firstTeacher, "", true, true, false, "1"));
        } else {
          scheduleList.add(new Schedule(dayParams, firstLesson, firstCabinet,
              firstTeacher, "", true, true, false, "1"));
        }
      } else if (dayParams == "2" || dayParams == "4" || dayParams == "6") {
        scheduleList.add(new Schedule(dayParams, firstLesson, firstCabinet,
            firstTeacher, "", false, false, true, dayParams));
      } else {
        if (count == 2) {
          scheduleList.add(new Schedule(dayParams, firstLesson, firstCabinet,
              firstTeacher, "", false, true, false, dayParams));
        } else {
          scheduleList.add(new Schedule(dayParams, firstLesson, firstCabinet,
              firstTeacher, "", false, false, false, dayParams));
        }
      }
      if (scheduleList.length == 6) {
        scheduleWeekList.add(ScheduleWeek(scheduleList));
        scheduleList.clear();
      }
    }
  }
  return scheduleList;
}

//Определяет первый ли это элемент в списке
bool isFirstElement(String str) {
  if (str.contains("Пн") ||
      str.contains("Вт") ||
      str.contains("Ср") ||
      str.contains("Чт") ||
      str.contains("Пт") ||
      str.contains("Сб") ||
      str.contains("Вс")) {
    return true;
  }
  return false;
}

==> schedule_package-0.0.665.tar.gz: lib/src/schedule_package.dart <==
import 'package:html/parser.dart' show parse;
import 'package:schedule_package/src/ScheduleModels/Schedule.dart';
import 'package:schedule_package/src/ScheduleModels/ScheduleWeek.dart';
import 'package:schedule_package/src/Supports/Decoder.dart';
import 'package:universal_html/parsing.dart' show parseHtmlDocument;

import '../src/ScheduleModels/Group.dart';
import "package:http/http.dart" as http;

import '../src/Supports/GlobalVariable.dart';

// Получает все группы которые есть на сайте
Future<List<Group>> getAllGroupsFuture() async {
  List<Group> groupsList = [];
  final response =
      await http.Client().get(Uri.parse(GlobalVariable.URL_MAIN + "/cg.htm"));
  if (response.statusCode == 200) {
    var body = decodeCp1251(response.body);
    var document = parse(body, encoding: 'windows-1251');
    var table = document
        .getElementsByClassName("inf")[0]
        .getElementsByTagName("tbody")[0];
    var res = table.getElementsByTagName("tr").length - 1;
    for (int i = 1; i <= res; i++) {
      var nameGroup = table
          .getElementsByTagName("tr")[i]
          .getElementsByTagName("td")[1]
          .text;
      var linkGroup = table
          .getElementsByTagName("tr")[i]
          .getElementsByTagName("td")[1]
          .getElementsByTagName("a")[0]
          .attributes;
      groupsList.add(Group(nameGroup, linkGroup["href"].toString()));
    }
  }
  return groupsList;
}

//Получает расписание группы по его Линку (ID)
Future<List<Schedule>> getScheduleFuture(String groupLink) async {
  List<Schedule> scheduleList = new List.empty();
  final response =
      await http.Client().get(Uri.parse(GlobalVariable.URL_MAIN + groupLink));
  if (response.statusCode == 200) {
    var body = decodeCp1251(response.body);
    var documentFullHtmlCode = parseHtmlDocument(body);
    var documentTableHtmlCode =
        documentFullHtmlCode.querySelectorAll("table.inf").first;
    var documentTableElements = documentTableHtmlCode.querySelectorAll("tr");
    int count = documentTableElements.length;
    for (int i = 3; i < count; i++) {
      var documentTableSelected = documentTableElements[i];

      String firstLesson = "",
          firstCabinet = "",
          firstTeacher = "",
          dayParams = "";

      int count = documentTableSelected.querySelectorAll("tr > td.ur").length;

      if (documentTableSelected.querySelector("tr > td.hd") != null)
        dayParams = documentTableSelected.querySelector("tr > td.hd")!.text!;
      if (documentTableSelected.querySelector("tr > td.ur > a.z1") != null)
        firstLesson =
            documentTableSelected.querySelector("tr > td.ur > a.z1")!.text!;
      if (documentTableSelected.querySelector("tr > td.ur > a.z2") != null)
        firstCabinet =
            documentTableSelected.querySelector("tr > td.ur > a.z2")!.text!;
      if (documentTableSelected.querySelector("tr > td.ur > a.z3") != null)
        firstTeacher =
            documentTableSelected.querySelector("tr > td.ur > a.z3")!.text!;

      if (isFirstElement(dayParams)) {
        if (count == 2) {
          scheduleList.add(new Schedule(dayParams, firstLesson, firstCabinet,
              firstTeacher, "", true, true, false, "1"));
        } else {
          scheduleList.add(new Schedule(dayParams, firstLesson, firstCabinet,
              firstTeacher, "", true, true, false, "1"));
        }
      } else if (dayParams == "2" || dayParams == "4" || dayParams == "6") {
        scheduleList.add(new Schedule(dayParams, firstLesson, firstCabinet,
            firstTeacher, "", false, false, true, dayParams));
      } else {
        if (count == 2) {
          scheduleList.add(new Schedule(dayParams, firstLesson, firstCabinet,
              firstTeacher, "", false, true, false, dayParams));
        } else {
          scheduleList.add(new Schedule(dayParams, firstLesson, firstCabinet,
              firstTeacher, "", false, false, false, dayParams));
        }
      }
    }
  }
  return scheduleList;
}

Future<List<ScheduleWeek>> getScheduleWeek(String groupLink) async {
  print("WEEEEEEEEEEEEEEEEEEEEEEK");
  List<ScheduleWeek> scheduleWeekList = [];
  List<Schedule> scheduleList = [];
  final response =
      await http.Client().get(Uri.parse(GlobalVariable.URL_MAIN + groupLink));
  if (response.statusCode == 200) {
    var body = decodeCp1251(response.body);
    var documentFullHtmlCode = parseHtmlDocument(body);
    var documentTableHtmlCode =
        documentFullHtmlCode.querySelectorAll("table.inf").first;
    var documentTableElements = documentTableHtmlCode.querySelectorAll("tr");
    int count = documentTableElements.length;
    for (int i = 3; i <= count-1; i += 6) {
      print(i.toString() + " : " + count.toString());
      for (int j = 0; j <= 5; j++) {
        print(j.toString() + " : " + i.toString());
        var documentTableSelected = documentTableElements[i + j];

        String firstLesson = "",
            firstCabinet = "",
            firstTeacher = "",
            dayParams = "";
        int countDouble =
            documentTableSelected.querySelectorAll("tr > td.ur").length;

        if (documentTableSelected.querySelector("tr > td.hd") != null)
          dayParams = documentTableSelected.querySelector("tr > td.hd")!.text!;
        if (documentTableSelected.querySelector("tr > td.ur > a.z1") != null)
          firstLesson =
              documentTableSelected.querySelector("tr > td.ur > a.z1")!.text!;
        if (documentTableSelected.querySelector("tr > td.ur > a.z2") != null)
          firstCabinet =
              documentTableSelected.querySelector("tr > td.ur > a.z2")!.text!;
        if (documentTableSelected.querySelector("tr > td.ur > a.z3") != null)
          firstTeacher =
              documentTableSelected.querySelector("tr > td.ur > a.z3")!.text!;

        if (isFirstElement(dayParams)) {
          if (countDouble == 2) {
            scheduleList.add(new Schedule(dayParams, firstLesson, firstCabinet,
                firstTeacher, "", true, true, false, "1"));
          } else {
            scheduleList.add(new Schedule(dayParams, firstLesson, firstCabinet,
                firstTeacher, "", true, true, false, "1"));
          }
        } else if (dayParams == "2" || dayParams == "4" || dayParams == "6") {
          scheduleList.add(new Schedule(dayParams, firstLesson, firstCabinet,
              firstTeacher, "", false, false, true, dayParams));
        } else {
          if (countDouble == 2) {
            scheduleList.add(new Schedule(dayParams, firstLesson, firstCabinet,
                firstTeacher, "", false, true, false, dayParams));
          } else {
            scheduleList.add(new Schedule(dayParams, firstLesson, firstCabinet,
                firstTeacher, "", false, false, false, dayParams));
          }
        }
        scheduleWeekList.add(ScheduleWeek(scheduleList));
        scheduleList.clear();
      }
    }
  }
  return scheduleWeekList;
}

//Определяет первый ли это элемент в списке
bool isFirstElement(String str) {
  if (str.contains("Пн") ||
      str.contains("Вт") ||
      str.contains("Ср") ||
      str.contains("Чт") ||
      str.contains("Пт") ||
      str.contains("Сб") ||
      str.contains("Вс")) {
    return true;
  }
  return false;
}
